# encoding: UTF-8
$censo = [
{:glosa=>"Alto Bío-Bío", :te=>1, :superficie=>161659.68, :ovinos=>8092, :bovinos=>7736},
{:glosa=>"Alto Bío-Bío", :te=>2, :superficie=>44214.8, :ovinos=>881, :bovinos=>1327},
{:glosa=>"Alto Bío-Bío", :te=>3, :superficie=>0, :ovinos=>45, :bovinos=>45},
{:glosa=>"Alto Bío-Bío", :te=>5, :superficie=>12451.1, :ovinos=>0, :bovinos=>0},
{:glosa=>"Antuco", :te=>1, :superficie=>67807.4, :ovinos=>1211, :bovinos=>1993},
{:glosa=>"Antuco", :te=>2, :superficie=>9449.69, :ovinos=>22, :bovinos=>57},
{:glosa=>"Antuco", :te=>3, :superficie=>0, :ovinos=>0, :bovinos=>0},
{:glosa=>"Antuco", :te=>5, :superficie=>12883, :ovinos=>0, :bovinos=>0},
{:glosa=>"Cabrero", :te=>1, :superficie=>33278.04, :ovinos=>1383, :bovinos=>16849},
{:glosa=>"Cabrero", :te=>2, :superficie=>26802.78, :ovinos=>5, :bovinos=>135},
{:glosa=>"Cabrero", :te=>3, :superficie=>0, :ovinos=>0, :bovinos=>0},
{:glosa=>"Laja", :te=>1, :superficie=>16540.64, :ovinos=>1953, :bovinos=>5818},
{:glosa=>"Laja", :te=>2, :superficie=>12741.56, :ovinos=>0, :bovinos=>52},
{:glosa=>"Laja", :te=>3, :superficie=>0, :ovinos=>0, :bovinos=>166},
{:glosa=>"Laja", :te=>4, :superficie=>0.1, :ovinos=>0, :bovinos=>0},
{:glosa=>"Los Angeles", :te=>1, :superficie=>120432.71, :ovinos=>3640, :bovinos=>87098},
{:glosa=>"Los Angeles", :te=>2, :superficie=>20205.1, :ovinos=>13, :bovinos=>219},
{:glosa=>"Los Angeles", :te=>3, :superficie=>0, :ovinos=>0, :bovinos=>9},
{:glosa=>"Los Angeles", :te=>4, :superficie=>19.4, :ovinos=>0, :bovinos=>0},
{:glosa=>"Mulchén", :te=>1, :superficie=>87515.1, :ovinos=>5472, :bovinos=>28562},
{:glosa=>"Mulchén", :te=>2, :superficie=>101300.3, :ovinos=>149, :bovinos=>279},
{:glosa=>"Mulchén", :te=>3, :superficie=>0, :ovinos=>22, :bovinos=>41},
{:glosa=>"Mulchén", :te=>4, :superficie=>10, :ovinos=>0, :bovinos=>0},
{:glosa=>"Nacimiento", :te=>1, :superficie=>25258.2, :ovinos=>2535, :bovinos=>4027},
{:glosa=>"Nacimiento", :te=>2, :superficie=>47295.23, :ovinos=>155, :bovinos=>266},
{:glosa=>"Nacimiento", :te=>3, :superficie=>0, :ovinos=>0, :bovinos=>3},
{:glosa=>"Negrete", :te=>1, :superficie=>10213.42, :ovinos=>564, :bovinos=>7424},
{:glosa=>"Negrete", :te=>2, :superficie=>1875.2, :ovinos=>0, :bovinos=>0},
{:glosa=>"Negrete", :te=>3, :superficie=>0, :ovinos=>0, :bovinos=>42},
{:glosa=>"Quilaco", :te=>1, :superficie=>21624.2, :ovinos=>5078, :bovinos=>5765},
{:glosa=>"Quilaco", :te=>2, :superficie=>70669.92, :ovinos=>71, :bovinos=>428},
{:glosa=>"Quilaco", :te=>3, :superficie=>0, :ovinos=>135, :bovinos=>359},
{:glosa=>"Quilaco", :te=>4, :superficie=>18.1, :ovinos=>0, :bovinos=>0},
{:glosa=>"Quilleco", :te=>1, :superficie=>46422.6399999999, :ovinos=>8635, :bovinos=>17881},
{:glosa=>"Quilleco", :te=>2, :superficie=>51873.11, :ovinos=>99, :bovinos=>161},
{:glosa=>"Quilleco", :te=>4, :superficie=>1089.7, :ovinos=>0, :bovinos=>0},
{:glosa=>"San Rosendo", :te=>1, :superficie=>3101.07, :ovinos=>52, :bovinos=>314},
{:glosa=>"San Rosendo", :te=>2, :superficie=>4809.14, :ovinos=>0, :bovinos=>10},
{:glosa=>"Santa Bárbara", :te=>1, :superficie=>91126.6000000003, :ovinos=>9540, :bovinos=>15316},
{:glosa=>"Santa Bárbara", :te=>2, :superficie=>30337.87, :ovinos=>273, :bovinos=>678},
{:glosa=>"Santa Bárbara", :te=>3, :superficie=>0, :ovinos=>12, :bovinos=>37},
{:glosa=>"Santa Bárbara", :te=>4, :superficie=>45.5, :ovinos=>0, :bovinos=>0},
{:glosa=>"Tucapel", :te=>1, :superficie=>76164.0399999999, :ovinos=>8941, :bovinos=>5436},
{:glosa=>"Tucapel", :te=>2, :superficie=>46603.55, :ovinos=>12, :bovinos=>60},
{:glosa=>"Tucapel", :te=>3, :superficie=>0, :ovinos=>18, :bovinos=>16},
{:glosa=>"Tucapel", :te=>4, :superficie=>7.8, :ovinos=>0, :bovinos=>0},
{:glosa=>"Yumbel", :te=>1, :superficie=>31260.98, :ovinos=>1462, :bovinos=>7899},
{:glosa=>"Yumbel", :te=>2, :superficie=>25284.95, :ovinos=>1, :bovinos=>52},
{:glosa=>"Yumbel", :te=>3, :superficie=>0, :ovinos=>3, :bovinos=>167},
{:glosa=>"Yumbel", :te=>4, :superficie=>7.1, :ovinos=>0, :bovinos=>0}
]
