$cars = [
{:name=>"chevrolet chevelle malibu", :mpg=>18, :cylinders=>8, :displacement=>307, :horsepower=>130, :weight=>3504, :acceleration=>12, :year=>70, :origin=>1},
{:name=>"buick skylark 320", :mpg=>15, :cylinders=>8, :displacement=>350, :horsepower=>165, :weight=>3693, :acceleration=>11.5, :year=>70, :origin=>1},
{:name=>"plymouth satellite", :mpg=>18, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>3436, :acceleration=>11, :year=>70, :origin=>1},
{:name=>"amc rebel sst", :mpg=>16, :cylinders=>8, :displacement=>304, :horsepower=>150, :weight=>3433, :acceleration=>12, :year=>70, :origin=>1},
{:name=>"ford torino", :mpg=>17, :cylinders=>8, :displacement=>302, :horsepower=>140, :weight=>3449, :acceleration=>10.5, :year=>70, :origin=>1},
{:name=>"ford galaxie 500", :mpg=>15, :cylinders=>8, :displacement=>429, :horsepower=>198, :weight=>4341, :acceleration=>10, :year=>70, :origin=>1},
{:name=>"chevrolet impala", :mpg=>14, :cylinders=>8, :displacement=>454, :horsepower=>220, :weight=>4354, :acceleration=>9, :year=>70, :origin=>1},
{:name=>"plymouth fury iii", :mpg=>14, :cylinders=>8, :displacement=>440, :horsepower=>215, :weight=>4312, :acceleration=>8.5, :year=>70, :origin=>1},
{:name=>"pontiac catalina", :mpg=>14, :cylinders=>8, :displacement=>455, :horsepower=>225, :weight=>4425, :acceleration=>10, :year=>70, :origin=>1},
{:name=>"amc ambassador dpl", :mpg=>15, :cylinders=>8, :displacement=>390, :horsepower=>190, :weight=>3850, :acceleration=>8.5, :year=>70, :origin=>1},
{:name=>"citroen ds-21 pallas", :mpg=>nil, :cylinders=>4, :displacement=>133, :horsepower=>115, :weight=>3090, :acceleration=>17.5, :year=>70, :origin=>2},
{:name=>"chevrolet chevelle concours (sw)", :mpg=>nil, :cylinders=>8, :displacement=>350, :horsepower=>165, :weight=>4142, :acceleration=>11.5, :year=>70, :origin=>1},
{:name=>"ford torino (sw)", :mpg=>nil, :cylinders=>8, :displacement=>351, :horsepower=>153, :weight=>4034, :acceleration=>11, :year=>70, :origin=>1},
{:name=>"plymouth satellite (sw)", :mpg=>nil, :cylinders=>8, :displacement=>383, :horsepower=>175, :weight=>4166, :acceleration=>10.5, :year=>70, :origin=>1},
{:name=>"amc rebel sst (sw)", :mpg=>nil, :cylinders=>8, :displacement=>360, :horsepower=>175, :weight=>3850, :acceleration=>11, :year=>70, :origin=>1},
{:name=>"dodge challenger se", :mpg=>15, :cylinders=>8, :displacement=>383, :horsepower=>170, :weight=>3563, :acceleration=>10, :year=>70, :origin=>1},
{:name=>"plymouth 'cuda 340", :mpg=>14, :cylinders=>8, :displacement=>340, :horsepower=>160, :weight=>3609, :acceleration=>8, :year=>70, :origin=>1},
{:name=>"ford mustang boss 302", :mpg=>nil, :cylinders=>8, :displacement=>302, :horsepower=>140, :weight=>3353, :acceleration=>8, :year=>70, :origin=>1},
{:name=>"chevrolet monte carlo", :mpg=>15, :cylinders=>8, :displacement=>400, :horsepower=>150, :weight=>3761, :acceleration=>9.5, :year=>70, :origin=>1},
{:name=>"buick estate wagon (sw)", :mpg=>14, :cylinders=>8, :displacement=>455, :horsepower=>225, :weight=>3086, :acceleration=>10, :year=>70, :origin=>1},
{:name=>"toyota corona mark ii", :mpg=>24, :cylinders=>4, :displacement=>113, :horsepower=>95, :weight=>2372, :acceleration=>15, :year=>70, :origin=>3},
{:name=>"plymouth duster", :mpg=>22, :cylinders=>6, :displacement=>198, :horsepower=>95, :weight=>2833, :acceleration=>15.5, :year=>70, :origin=>1},
{:name=>"amc hornet", :mpg=>18, :cylinders=>6, :displacement=>199, :horsepower=>97, :weight=>2774, :acceleration=>15.5, :year=>70, :origin=>1},
{:name=>"ford maverick", :mpg=>21, :cylinders=>6, :displacement=>200, :horsepower=>85, :weight=>2587, :acceleration=>16, :year=>70, :origin=>1},
{:name=>"datsun pl510", :mpg=>27, :cylinders=>4, :displacement=>97, :horsepower=>88, :weight=>2130, :acceleration=>14.5, :year=>70, :origin=>3},
{:name=>"volkswagen 1131 deluxe sedan", :mpg=>26, :cylinders=>4, :displacement=>97, :horsepower=>46, :weight=>1835, :acceleration=>20.5, :year=>70, :origin=>2},
{:name=>"peugeot 504", :mpg=>25, :cylinders=>4, :displacement=>110, :horsepower=>87, :weight=>2672, :acceleration=>17.5, :year=>70, :origin=>2},
{:name=>"audi 100 ls", :mpg=>24, :cylinders=>4, :displacement=>107, :horsepower=>90, :weight=>2430, :acceleration=>14.5, :year=>70, :origin=>2},
{:name=>"saab 99e", :mpg=>25, :cylinders=>4, :displacement=>104, :horsepower=>95, :weight=>2375, :acceleration=>17.5, :year=>70, :origin=>2},
{:name=>"bmw 2002", :mpg=>26, :cylinders=>4, :displacement=>121, :horsepower=>113, :weight=>2234, :acceleration=>12.5, :year=>70, :origin=>2},
{:name=>"amc gremlin", :mpg=>21, :cylinders=>6, :displacement=>199, :horsepower=>90, :weight=>2648, :acceleration=>15, :year=>70, :origin=>1},
{:name=>"ford f250", :mpg=>10, :cylinders=>8, :displacement=>360, :horsepower=>215, :weight=>4615, :acceleration=>14, :year=>70, :origin=>1},
{:name=>"chevy c20", :mpg=>10, :cylinders=>8, :displacement=>307, :horsepower=>200, :weight=>4376, :acceleration=>15, :year=>70, :origin=>1},
{:name=>"dodge d200", :mpg=>11, :cylinders=>8, :displacement=>318, :horsepower=>210, :weight=>4382, :acceleration=>13.5, :year=>70, :origin=>1},
{:name=>"hi 1200d", :mpg=>9, :cylinders=>8, :displacement=>304, :horsepower=>193, :weight=>4732, :acceleration=>18.5, :year=>70, :origin=>1},
{:name=>"datsun pl510", :mpg=>27, :cylinders=>4, :displacement=>97, :horsepower=>88, :weight=>2130, :acceleration=>14.5, :year=>71, :origin=>3},
{:name=>"chevrolet vega 2300", :mpg=>28, :cylinders=>4, :displacement=>140, :horsepower=>90, :weight=>2264, :acceleration=>15.5, :year=>71, :origin=>1},
{:name=>"toyota corona", :mpg=>25, :cylinders=>4, :displacement=>113, :horsepower=>95, :weight=>2228, :acceleration=>14, :year=>71, :origin=>3},
{:name=>"ford pinto", :mpg=>25, :cylinders=>4, :displacement=>98, :horsepower=>nil, :weight=>2046, :acceleration=>19, :year=>71, :origin=>1},
{:name=>"volkswagen super beetle 117", :mpg=>nil, :cylinders=>4, :displacement=>97, :horsepower=>48, :weight=>1978, :acceleration=>20, :year=>71, :origin=>2},
{:name=>"amc gremlin", :mpg=>19, :cylinders=>6, :displacement=>232, :horsepower=>100, :weight=>2634, :acceleration=>13, :year=>71, :origin=>1},
{:name=>"plymouth satellite custom", :mpg=>16, :cylinders=>6, :displacement=>225, :horsepower=>105, :weight=>3439, :acceleration=>15.5, :year=>71, :origin=>1},
{:name=>"chevrolet chevelle malibu", :mpg=>17, :cylinders=>6, :displacement=>250, :horsepower=>100, :weight=>3329, :acceleration=>15.5, :year=>71, :origin=>1},
{:name=>"ford torino 500", :mpg=>19, :cylinders=>6, :displacement=>250, :horsepower=>88, :weight=>3302, :acceleration=>15.5, :year=>71, :origin=>1},
{:name=>"amc matador", :mpg=>18, :cylinders=>6, :displacement=>232, :horsepower=>100, :weight=>3288, :acceleration=>15.5, :year=>71, :origin=>1},
{:name=>"chevrolet impala", :mpg=>14, :cylinders=>8, :displacement=>350, :horsepower=>165, :weight=>4209, :acceleration=>12, :year=>71, :origin=>1},
{:name=>"pontiac catalina brougham", :mpg=>14, :cylinders=>8, :displacement=>400, :horsepower=>175, :weight=>4464, :acceleration=>11.5, :year=>71, :origin=>1},
{:name=>"ford galaxie 500", :mpg=>14, :cylinders=>8, :displacement=>351, :horsepower=>153, :weight=>4154, :acceleration=>13.5, :year=>71, :origin=>1},
{:name=>"plymouth fury iii", :mpg=>14, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4096, :acceleration=>13, :year=>71, :origin=>1},
{:name=>"dodge monaco (sw)", :mpg=>12, :cylinders=>8, :displacement=>383, :horsepower=>180, :weight=>4955, :acceleration=>11.5, :year=>71, :origin=>1},
{:name=>"ford country squire (sw)", :mpg=>13, :cylinders=>8, :displacement=>400, :horsepower=>170, :weight=>4746, :acceleration=>12, :year=>71, :origin=>1},
{:name=>"pontiac safari (sw)", :mpg=>13, :cylinders=>8, :displacement=>400, :horsepower=>175, :weight=>5140, :acceleration=>12, :year=>71, :origin=>1},
{:name=>"amc hornet sportabout (sw)", :mpg=>18, :cylinders=>6, :displacement=>258, :horsepower=>110, :weight=>2962, :acceleration=>13.5, :year=>71, :origin=>1},
{:name=>"chevrolet vega (sw)", :mpg=>22, :cylinders=>4, :displacement=>140, :horsepower=>72, :weight=>2408, :acceleration=>19, :year=>71, :origin=>1},
{:name=>"pontiac firebird", :mpg=>19, :cylinders=>6, :displacement=>250, :horsepower=>100, :weight=>3282, :acceleration=>15, :year=>71, :origin=>1},
{:name=>"ford mustang", :mpg=>18, :cylinders=>6, :displacement=>250, :horsepower=>88, :weight=>3139, :acceleration=>14.5, :year=>71, :origin=>1},
{:name=>"mercury capri 2000", :mpg=>23, :cylinders=>4, :displacement=>122, :horsepower=>86, :weight=>2220, :acceleration=>14, :year=>71, :origin=>1},
{:name=>"opel 1900", :mpg=>28, :cylinders=>4, :displacement=>116, :horsepower=>90, :weight=>2123, :acceleration=>14, :year=>71, :origin=>2},
{:name=>"peugeot 304", :mpg=>30, :cylinders=>4, :displacement=>79, :horsepower=>70, :weight=>2074, :acceleration=>19.5, :year=>71, :origin=>2},
{:name=>"fiat 124b", :mpg=>30, :cylinders=>4, :displacement=>88, :horsepower=>76, :weight=>2065, :acceleration=>14.5, :year=>71, :origin=>2},
{:name=>"toyota corolla 1200", :mpg=>31, :cylinders=>4, :displacement=>71, :horsepower=>65, :weight=>1773, :acceleration=>19, :year=>71, :origin=>3},
{:name=>"datsun 1200", :mpg=>35, :cylinders=>4, :displacement=>72, :horsepower=>69, :weight=>1613, :acceleration=>18, :year=>71, :origin=>3},
{:name=>"volkswagen model 111", :mpg=>27, :cylinders=>4, :displacement=>97, :horsepower=>60, :weight=>1834, :acceleration=>19, :year=>71, :origin=>2},
{:name=>"plymouth cricket", :mpg=>26, :cylinders=>4, :displacement=>91, :horsepower=>70, :weight=>1955, :acceleration=>20.5, :year=>71, :origin=>1},
{:name=>"toyota corona hardtop", :mpg=>24, :cylinders=>4, :displacement=>113, :horsepower=>95, :weight=>2278, :acceleration=>15.5, :year=>72, :origin=>3},
{:name=>"dodge colt hardtop", :mpg=>25, :cylinders=>4, :displacement=>97.5, :horsepower=>80, :weight=>2126, :acceleration=>17, :year=>72, :origin=>1},
{:name=>"volkswagen type 3", :mpg=>23, :cylinders=>4, :displacement=>97, :horsepower=>54, :weight=>2254, :acceleration=>23.5, :year=>72, :origin=>2},
{:name=>"chevrolet vega", :mpg=>20, :cylinders=>4, :displacement=>140, :horsepower=>90, :weight=>2408, :acceleration=>19.5, :year=>72, :origin=>1},
{:name=>"ford pinto runabout", :mpg=>21, :cylinders=>4, :displacement=>122, :horsepower=>86, :weight=>2226, :acceleration=>16.5, :year=>72, :origin=>1},
{:name=>"chevrolet impala", :mpg=>13, :cylinders=>8, :displacement=>350, :horsepower=>165, :weight=>4274, :acceleration=>12, :year=>72, :origin=>1},
{:name=>"pontiac catalina", :mpg=>14, :cylinders=>8, :displacement=>400, :horsepower=>175, :weight=>4385, :acceleration=>12, :year=>72, :origin=>1},
{:name=>"plymouth fury iii", :mpg=>15, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4135, :acceleration=>13.5, :year=>72, :origin=>1},
{:name=>"ford galaxie 500", :mpg=>14, :cylinders=>8, :displacement=>351, :horsepower=>153, :weight=>4129, :acceleration=>13, :year=>72, :origin=>1},
{:name=>"amc ambassador sst", :mpg=>17, :cylinders=>8, :displacement=>304, :horsepower=>150, :weight=>3672, :acceleration=>11.5, :year=>72, :origin=>1},
{:name=>"mercury marquis", :mpg=>11, :cylinders=>8, :displacement=>429, :horsepower=>208, :weight=>4633, :acceleration=>11, :year=>72, :origin=>1},
{:name=>"buick lesabre custom", :mpg=>13, :cylinders=>8, :displacement=>350, :horsepower=>155, :weight=>4502, :acceleration=>13.5, :year=>72, :origin=>1},
{:name=>"oldsmobile delta 88 royale", :mpg=>12, :cylinders=>8, :displacement=>350, :horsepower=>160, :weight=>4456, :acceleration=>13.5, :year=>72, :origin=>1},
{:name=>"chrysler newport royal", :mpg=>13, :cylinders=>8, :displacement=>400, :horsepower=>190, :weight=>4422, :acceleration=>12.5, :year=>72, :origin=>1},
{:name=>"mazda rx2 coupe", :mpg=>19, :cylinders=>3, :displacement=>70, :horsepower=>97, :weight=>2330, :acceleration=>13.5, :year=>72, :origin=>3},
{:name=>"amc matador (sw)", :mpg=>15, :cylinders=>8, :displacement=>304, :horsepower=>150, :weight=>3892, :acceleration=>12.5, :year=>72, :origin=>1},
{:name=>"chevrolet chevelle concours (sw)", :mpg=>13, :cylinders=>8, :displacement=>307, :horsepower=>130, :weight=>4098, :acceleration=>14, :year=>72, :origin=>1},
{:name=>"ford gran torino (sw)", :mpg=>13, :cylinders=>8, :displacement=>302, :horsepower=>140, :weight=>4294, :acceleration=>16, :year=>72, :origin=>1},
{:name=>"plymouth satellite custom (sw)", :mpg=>14, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4077, :acceleration=>14, :year=>72, :origin=>1},
{:name=>"volvo 145e (sw)", :mpg=>18, :cylinders=>4, :displacement=>121, :horsepower=>112, :weight=>2933, :acceleration=>14.5, :year=>72, :origin=>2},
{:name=>"volkswagen 411 (sw)", :mpg=>22, :cylinders=>4, :displacement=>121, :horsepower=>76, :weight=>2511, :acceleration=>18, :year=>72, :origin=>2},
{:name=>"peugeot 504 (sw)", :mpg=>21, :cylinders=>4, :displacement=>120, :horsepower=>87, :weight=>2979, :acceleration=>19.5, :year=>72, :origin=>2},
{:name=>"renault 12 (sw)", :mpg=>26, :cylinders=>4, :displacement=>96, :horsepower=>69, :weight=>2189, :acceleration=>18, :year=>72, :origin=>2},
{:name=>"ford pinto (sw)", :mpg=>22, :cylinders=>4, :displacement=>122, :horsepower=>86, :weight=>2395, :acceleration=>16, :year=>72, :origin=>1},
{:name=>"datsun 510 (sw)", :mpg=>28, :cylinders=>4, :displacement=>97, :horsepower=>92, :weight=>2288, :acceleration=>17, :year=>72, :origin=>3},
{:name=>"toyouta corona mark ii (sw)", :mpg=>23, :cylinders=>4, :displacement=>120, :horsepower=>97, :weight=>2506, :acceleration=>14.5, :year=>72, :origin=>3},
{:name=>"dodge colt (sw)", :mpg=>28, :cylinders=>4, :displacement=>98, :horsepower=>80, :weight=>2164, :acceleration=>15, :year=>72, :origin=>1},
{:name=>"toyota corolla 1600 (sw)", :mpg=>27, :cylinders=>4, :displacement=>97, :horsepower=>88, :weight=>2100, :acceleration=>16.5, :year=>72, :origin=>3},
{:name=>"buick century 350", :mpg=>13, :cylinders=>8, :displacement=>350, :horsepower=>175, :weight=>4100, :acceleration=>13, :year=>73, :origin=>1},
{:name=>"amc matador", :mpg=>14, :cylinders=>8, :displacement=>304, :horsepower=>150, :weight=>3672, :acceleration=>11.5, :year=>73, :origin=>1},
{:name=>"chevrolet malibu", :mpg=>13, :cylinders=>8, :displacement=>350, :horsepower=>145, :weight=>3988, :acceleration=>13, :year=>73, :origin=>1},
{:name=>"ford gran torino", :mpg=>14, :cylinders=>8, :displacement=>302, :horsepower=>137, :weight=>4042, :acceleration=>14.5, :year=>73, :origin=>1},
{:name=>"dodge coronet custom", :mpg=>15, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>3777, :acceleration=>12.5, :year=>73, :origin=>1},
{:name=>"mercury marquis brougham", :mpg=>12, :cylinders=>8, :displacement=>429, :horsepower=>198, :weight=>4952, :acceleration=>11.5, :year=>73, :origin=>1},
{:name=>"chevrolet caprice classic", :mpg=>13, :cylinders=>8, :displacement=>400, :horsepower=>150, :weight=>4464, :acceleration=>12, :year=>73, :origin=>1},
{:name=>"ford ltd", :mpg=>13, :cylinders=>8, :displacement=>351, :horsepower=>158, :weight=>4363, :acceleration=>13, :year=>73, :origin=>1},
{:name=>"plymouth fury gran sedan", :mpg=>14, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4237, :acceleration=>14.5, :year=>73, :origin=>1},
{:name=>"chrysler new yorker brougham", :mpg=>13, :cylinders=>8, :displacement=>440, :horsepower=>215, :weight=>4735, :acceleration=>11, :year=>73, :origin=>1},
{:name=>"buick electra 225 custom", :mpg=>12, :cylinders=>8, :displacement=>455, :horsepower=>225, :weight=>4951, :acceleration=>11, :year=>73, :origin=>1},
{:name=>"amc ambassador brougham", :mpg=>13, :cylinders=>8, :displacement=>360, :horsepower=>175, :weight=>3821, :acceleration=>11, :year=>73, :origin=>1},
{:name=>"plymouth valiant", :mpg=>18, :cylinders=>6, :displacement=>225, :horsepower=>105, :weight=>3121, :acceleration=>16.5, :year=>73, :origin=>1},
{:name=>"chevrolet nova custom", :mpg=>16, :cylinders=>6, :displacement=>250, :horsepower=>100, :weight=>3278, :acceleration=>18, :year=>73, :origin=>1},
{:name=>"amc hornet", :mpg=>18, :cylinders=>6, :displacement=>232, :horsepower=>100, :weight=>2945, :acceleration=>16, :year=>73, :origin=>1},
{:name=>"ford maverick", :mpg=>18, :cylinders=>6, :displacement=>250, :horsepower=>88, :weight=>3021, :acceleration=>16.5, :year=>73, :origin=>1},
{:name=>"plymouth duster", :mpg=>23, :cylinders=>6, :displacement=>198, :horsepower=>95, :weight=>2904, :acceleration=>16, :year=>73, :origin=>1},
{:name=>"volkswagen super beetle", :mpg=>26, :cylinders=>4, :displacement=>97, :horsepower=>46, :weight=>1950, :acceleration=>21, :year=>73, :origin=>2},
{:name=>"chevrolet impala", :mpg=>11, :cylinders=>8, :displacement=>400, :horsepower=>150, :weight=>4997, :acceleration=>14, :year=>73, :origin=>1},
{:name=>"ford country", :mpg=>12, :cylinders=>8, :displacement=>400, :horsepower=>167, :weight=>4906, :acceleration=>12.5, :year=>73, :origin=>1},
{:name=>"plymouth custom suburb", :mpg=>13, :cylinders=>8, :displacement=>360, :horsepower=>170, :weight=>4654, :acceleration=>13, :year=>73, :origin=>1},
{:name=>"oldsmobile vista cruiser", :mpg=>12, :cylinders=>8, :displacement=>350, :horsepower=>180, :weight=>4499, :acceleration=>12.5, :year=>73, :origin=>1},
{:name=>"amc gremlin", :mpg=>18, :cylinders=>6, :displacement=>232, :horsepower=>100, :weight=>2789, :acceleration=>15, :year=>73, :origin=>1},
{:name=>"toyota carina", :mpg=>20, :cylinders=>4, :displacement=>97, :horsepower=>88, :weight=>2279, :acceleration=>19, :year=>73, :origin=>3},
{:name=>"chevrolet vega", :mpg=>21, :cylinders=>4, :displacement=>140, :horsepower=>72, :weight=>2401, :acceleration=>19.5, :year=>73, :origin=>1},
{:name=>"datsun 610", :mpg=>22, :cylinders=>4, :displacement=>108, :horsepower=>94, :weight=>2379, :acceleration=>16.5, :year=>73, :origin=>3},
{:name=>"maxda rx3", :mpg=>18, :cylinders=>3, :displacement=>70, :horsepower=>90, :weight=>2124, :acceleration=>13.5, :year=>73, :origin=>3},
{:name=>"ford pinto", :mpg=>19, :cylinders=>4, :displacement=>122, :horsepower=>85, :weight=>2310, :acceleration=>18.5, :year=>73, :origin=>1},
{:name=>"mercury capri v6", :mpg=>21, :cylinders=>6, :displacement=>155, :horsepower=>107, :weight=>2472, :acceleration=>14, :year=>73, :origin=>1},
{:name=>"fiat 124 sport coupe", :mpg=>26, :cylinders=>4, :displacement=>98, :horsepower=>90, :weight=>2265, :acceleration=>15.5, :year=>73, :origin=>2},
{:name=>"chevrolet monte carlo s", :mpg=>15, :cylinders=>8, :displacement=>350, :horsepower=>145, :weight=>4082, :acceleration=>13, :year=>73, :origin=>1},
{:name=>"pontiac grand prix", :mpg=>16, :cylinders=>8, :displacement=>400, :horsepower=>230, :weight=>4278, :acceleration=>9.5, :year=>73, :origin=>1},
{:name=>"fiat 128", :mpg=>29, :cylinders=>4, :displacement=>68, :horsepower=>49, :weight=>1867, :acceleration=>19.5, :year=>73, :origin=>2},
{:name=>"opel manta", :mpg=>24, :cylinders=>4, :displacement=>116, :horsepower=>75, :weight=>2158, :acceleration=>15.5, :year=>73, :origin=>2},
{:name=>"audi 100ls", :mpg=>20, :cylinders=>4, :displacement=>114, :horsepower=>91, :weight=>2582, :acceleration=>14, :year=>73, :origin=>2},
{:name=>"volvo 144ea", :mpg=>19, :cylinders=>4, :displacement=>121, :horsepower=>112, :weight=>2868, :acceleration=>15.5, :year=>73, :origin=>2},
{:name=>"dodge dart custom", :mpg=>15, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>3399, :acceleration=>11, :year=>73, :origin=>1},
{:name=>"saab 99le", :mpg=>24, :cylinders=>4, :displacement=>121, :horsepower=>110, :weight=>2660, :acceleration=>14, :year=>73, :origin=>2},
{:name=>"toyota mark ii", :mpg=>20, :cylinders=>6, :displacement=>156, :horsepower=>122, :weight=>2807, :acceleration=>13.5, :year=>73, :origin=>3},
{:name=>"oldsmobile omega", :mpg=>11, :cylinders=>8, :displacement=>350, :horsepower=>180, :weight=>3664, :acceleration=>11, :year=>73, :origin=>1},
{:name=>"plymouth duster", :mpg=>20, :cylinders=>6, :displacement=>198, :horsepower=>95, :weight=>3102, :acceleration=>16.5, :year=>74, :origin=>1},
{:name=>"ford maverick", :mpg=>21, :cylinders=>6, :displacement=>200, :horsepower=>nil, :weight=>2875, :acceleration=>17, :year=>74, :origin=>1},
{:name=>"amc hornet", :mpg=>19, :cylinders=>6, :displacement=>232, :horsepower=>100, :weight=>2901, :acceleration=>16, :year=>74, :origin=>1},
{:name=>"chevrolet nova", :mpg=>15, :cylinders=>6, :displacement=>250, :horsepower=>100, :weight=>3336, :acceleration=>17, :year=>74, :origin=>1},
{:name=>"datsun b210", :mpg=>31, :cylinders=>4, :displacement=>79, :horsepower=>67, :weight=>1950, :acceleration=>19, :year=>74, :origin=>3},
{:name=>"ford pinto", :mpg=>26, :cylinders=>4, :displacement=>122, :horsepower=>80, :weight=>2451, :acceleration=>16.5, :year=>74, :origin=>1},
{:name=>"toyota corolla 1200", :mpg=>32, :cylinders=>4, :displacement=>71, :horsepower=>65, :weight=>1836, :acceleration=>21, :year=>74, :origin=>3},
{:name=>"chevrolet vega", :mpg=>25, :cylinders=>4, :displacement=>140, :horsepower=>75, :weight=>2542, :acceleration=>17, :year=>74, :origin=>1},
{:name=>"chevrolet chevelle malibu classic", :mpg=>16, :cylinders=>6, :displacement=>250, :horsepower=>100, :weight=>3781, :acceleration=>17, :year=>74, :origin=>1},
{:name=>"amc matador", :mpg=>16, :cylinders=>6, :displacement=>258, :horsepower=>110, :weight=>3632, :acceleration=>18, :year=>74, :origin=>1},
{:name=>"plymouth satellite sebring", :mpg=>18, :cylinders=>6, :displacement=>225, :horsepower=>105, :weight=>3613, :acceleration=>16.5, :year=>74, :origin=>1},
{:name=>"ford gran torino", :mpg=>16, :cylinders=>8, :displacement=>302, :horsepower=>140, :weight=>4141, :acceleration=>14, :year=>74, :origin=>1},
{:name=>"buick century luxus (sw)", :mpg=>13, :cylinders=>8, :displacement=>350, :horsepower=>150, :weight=>4699, :acceleration=>14.5, :year=>74, :origin=>1},
{:name=>"dodge coronet custom (sw)", :mpg=>14, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4457, :acceleration=>13.5, :year=>74, :origin=>1},
{:name=>"ford gran torino (sw)", :mpg=>14, :cylinders=>8, :displacement=>302, :horsepower=>140, :weight=>4638, :acceleration=>16, :year=>74, :origin=>1},
{:name=>"amc matador (sw)", :mpg=>14, :cylinders=>8, :displacement=>304, :horsepower=>150, :weight=>4257, :acceleration=>15.5, :year=>74, :origin=>1},
{:name=>"audi fox", :mpg=>29, :cylinders=>4, :displacement=>98, :horsepower=>83, :weight=>2219, :acceleration=>16.5, :year=>74, :origin=>2},
{:name=>"volkswagen dasher", :mpg=>26, :cylinders=>4, :displacement=>79, :horsepower=>67, :weight=>1963, :acceleration=>15.5, :year=>74, :origin=>2},
{:name=>"opel manta", :mpg=>26, :cylinders=>4, :displacement=>97, :horsepower=>78, :weight=>2300, :acceleration=>14.5, :year=>74, :origin=>2},
{:name=>"toyota corona", :mpg=>31, :cylinders=>4, :displacement=>76, :horsepower=>52, :weight=>1649, :acceleration=>16.5, :year=>74, :origin=>3},
{:name=>"datsun 710", :mpg=>32, :cylinders=>4, :displacement=>83, :horsepower=>61, :weight=>2003, :acceleration=>19, :year=>74, :origin=>3},
{:name=>"dodge colt", :mpg=>28, :cylinders=>4, :displacement=>90, :horsepower=>75, :weight=>2125, :acceleration=>14.5, :year=>74, :origin=>1},
{:name=>"fiat 128", :mpg=>24, :cylinders=>4, :displacement=>90, :horsepower=>75, :weight=>2108, :acceleration=>15.5, :year=>74, :origin=>2},
{:name=>"fiat 124 tc", :mpg=>26, :cylinders=>4, :displacement=>116, :horsepower=>75, :weight=>2246, :acceleration=>14, :year=>74, :origin=>2},
{:name=>"honda civic", :mpg=>24, :cylinders=>4, :displacement=>120, :horsepower=>97, :weight=>2489, :acceleration=>15, :year=>74, :origin=>3},
{:name=>"subaru", :mpg=>26, :cylinders=>4, :displacement=>108, :horsepower=>93, :weight=>2391, :acceleration=>15.5, :year=>74, :origin=>3},
{:name=>"fiat x1.9", :mpg=>31, :cylinders=>4, :displacement=>79, :horsepower=>67, :weight=>2000, :acceleration=>16, :year=>74, :origin=>2},
{:name=>"plymouth valiant custom", :mpg=>19, :cylinders=>6, :displacement=>225, :horsepower=>95, :weight=>3264, :acceleration=>16, :year=>75, :origin=>1},
{:name=>"chevrolet nova", :mpg=>18, :cylinders=>6, :displacement=>250, :horsepower=>105, :weight=>3459, :acceleration=>16, :year=>75, :origin=>1},
{:name=>"mercury monarch", :mpg=>15, :cylinders=>6, :displacement=>250, :horsepower=>72, :weight=>3432, :acceleration=>21, :year=>75, :origin=>1},
{:name=>"ford maverick", :mpg=>15, :cylinders=>6, :displacement=>250, :horsepower=>72, :weight=>3158, :acceleration=>19.5, :year=>75, :origin=>1},
{:name=>"pontiac catalina", :mpg=>16, :cylinders=>8, :displacement=>400, :horsepower=>170, :weight=>4668, :acceleration=>11.5, :year=>75, :origin=>1},
{:name=>"chevrolet bel air", :mpg=>15, :cylinders=>8, :displacement=>350, :horsepower=>145, :weight=>4440, :acceleration=>14, :year=>75, :origin=>1},
{:name=>"plymouth grand fury", :mpg=>16, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4498, :acceleration=>14.5, :year=>75, :origin=>1},
{:name=>"ford ltd", :mpg=>14, :cylinders=>8, :displacement=>351, :horsepower=>148, :weight=>4657, :acceleration=>13.5, :year=>75, :origin=>1},
{:name=>"buick century", :mpg=>17, :cylinders=>6, :displacement=>231, :horsepower=>110, :weight=>3907, :acceleration=>21, :year=>75, :origin=>1},
{:name=>"chevroelt chevelle malibu", :mpg=>16, :cylinders=>6, :displacement=>250, :horsepower=>105, :weight=>3897, :acceleration=>18.5, :year=>75, :origin=>1},
{:name=>"amc matador", :mpg=>15, :cylinders=>6, :displacement=>258, :horsepower=>110, :weight=>3730, :acceleration=>19, :year=>75, :origin=>1},
{:name=>"plymouth fury", :mpg=>18, :cylinders=>6, :displacement=>225, :horsepower=>95, :weight=>3785, :acceleration=>19, :year=>75, :origin=>1},
{:name=>"buick skyhawk", :mpg=>21, :cylinders=>6, :displacement=>231, :horsepower=>110, :weight=>3039, :acceleration=>15, :year=>75, :origin=>1},
{:name=>"chevrolet monza 2+2", :mpg=>20, :cylinders=>8, :displacement=>262, :horsepower=>110, :weight=>3221, :acceleration=>13.5, :year=>75, :origin=>1},
{:name=>"ford mustang ii", :mpg=>13, :cylinders=>8, :displacement=>302, :horsepower=>129, :weight=>3169, :acceleration=>12, :year=>75, :origin=>1},
{:name=>"toyota corolla", :mpg=>29, :cylinders=>4, :displacement=>97, :horsepower=>75, :weight=>2171, :acceleration=>16, :year=>75, :origin=>3},
{:name=>"ford pinto", :mpg=>23, :cylinders=>4, :displacement=>140, :horsepower=>83, :weight=>2639, :acceleration=>17, :year=>75, :origin=>1},
{:name=>"amc gremlin", :mpg=>20, :cylinders=>6, :displacement=>232, :horsepower=>100, :weight=>2914, :acceleration=>16, :year=>75, :origin=>1},
{:name=>"pontiac astro", :mpg=>23, :cylinders=>4, :displacement=>140, :horsepower=>78, :weight=>2592, :acceleration=>18.5, :year=>75, :origin=>1},
{:name=>"toyota corona", :mpg=>24, :cylinders=>4, :displacement=>134, :horsepower=>96, :weight=>2702, :acceleration=>13.5, :year=>75, :origin=>3},
{:name=>"volkswagen dasher", :mpg=>25, :cylinders=>4, :displacement=>90, :horsepower=>71, :weight=>2223, :acceleration=>16.5, :year=>75, :origin=>2},
{:name=>"datsun 710", :mpg=>24, :cylinders=>4, :displacement=>119, :horsepower=>97, :weight=>2545, :acceleration=>17, :year=>75, :origin=>3},
{:name=>"ford pinto", :mpg=>18, :cylinders=>6, :displacement=>171, :horsepower=>97, :weight=>2984, :acceleration=>14.5, :year=>75, :origin=>1},
{:name=>"volkswagen rabbit", :mpg=>29, :cylinders=>4, :displacement=>90, :horsepower=>70, :weight=>1937, :acceleration=>14, :year=>75, :origin=>2},
{:name=>"amc pacer", :mpg=>19, :cylinders=>6, :displacement=>232, :horsepower=>90, :weight=>3211, :acceleration=>17, :year=>75, :origin=>1},
{:name=>"audi 100ls", :mpg=>23, :cylinders=>4, :displacement=>115, :horsepower=>95, :weight=>2694, :acceleration=>15, :year=>75, :origin=>2},
{:name=>"peugeot 504", :mpg=>23, :cylinders=>4, :displacement=>120, :horsepower=>88, :weight=>2957, :acceleration=>17, :year=>75, :origin=>2},
{:name=>"volvo 244dl", :mpg=>22, :cylinders=>4, :displacement=>121, :horsepower=>98, :weight=>2945, :acceleration=>14.5, :year=>75, :origin=>2},
{:name=>"saab 99le", :mpg=>25, :cylinders=>4, :displacement=>121, :horsepower=>115, :weight=>2671, :acceleration=>13.5, :year=>75, :origin=>2},
{:name=>"honda civic cvcc", :mpg=>33, :cylinders=>4, :displacement=>91, :horsepower=>53, :weight=>1795, :acceleration=>17.5, :year=>75, :origin=>3},
{:name=>"fiat 131", :mpg=>28, :cylinders=>4, :displacement=>107, :horsepower=>86, :weight=>2464, :acceleration=>15.5, :year=>76, :origin=>2},
{:name=>"opel 1900", :mpg=>25, :cylinders=>4, :displacement=>116, :horsepower=>81, :weight=>2220, :acceleration=>16.9, :year=>76, :origin=>2},
{:name=>"capri ii", :mpg=>25, :cylinders=>4, :displacement=>140, :horsepower=>92, :weight=>2572, :acceleration=>14.9, :year=>76, :origin=>1},
{:name=>"dodge colt", :mpg=>26, :cylinders=>4, :displacement=>98, :horsepower=>79, :weight=>2255, :acceleration=>17.7, :year=>76, :origin=>1},
{:name=>"renault 12tl", :mpg=>27, :cylinders=>4, :displacement=>101, :horsepower=>83, :weight=>2202, :acceleration=>15.3, :year=>76, :origin=>2},
{:name=>"chevrolet chevelle malibu classic", :mpg=>17.5, :cylinders=>8, :displacement=>305, :horsepower=>140, :weight=>4215, :acceleration=>13, :year=>76, :origin=>1},
{:name=>"dodge coronet brougham", :mpg=>16, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>4190, :acceleration=>13, :year=>76, :origin=>1},
{:name=>"amc matador", :mpg=>15.5, :cylinders=>8, :displacement=>304, :horsepower=>120, :weight=>3962, :acceleration=>13.9, :year=>76, :origin=>1},
{:name=>"ford gran torino", :mpg=>14.5, :cylinders=>8, :displacement=>351, :horsepower=>152, :weight=>4215, :acceleration=>12.8, :year=>76, :origin=>1},
{:name=>"plymouth valiant", :mpg=>22, :cylinders=>6, :displacement=>225, :horsepower=>100, :weight=>3233, :acceleration=>15.4, :year=>76, :origin=>1},
{:name=>"chevrolet nova", :mpg=>22, :cylinders=>6, :displacement=>250, :horsepower=>105, :weight=>3353, :acceleration=>14.5, :year=>76, :origin=>1},
{:name=>"ford maverick", :mpg=>24, :cylinders=>6, :displacement=>200, :horsepower=>81, :weight=>3012, :acceleration=>17.6, :year=>76, :origin=>1},
{:name=>"amc hornet", :mpg=>22.5, :cylinders=>6, :displacement=>232, :horsepower=>90, :weight=>3085, :acceleration=>17.6, :year=>76, :origin=>1},
{:name=>"chevrolet chevette", :mpg=>29, :cylinders=>4, :displacement=>85, :horsepower=>52, :weight=>2035, :acceleration=>22.2, :year=>76, :origin=>1},
{:name=>"chevrolet woody", :mpg=>24.5, :cylinders=>4, :displacement=>98, :horsepower=>60, :weight=>2164, :acceleration=>22.1, :year=>76, :origin=>1},
{:name=>"vw rabbit", :mpg=>29, :cylinders=>4, :displacement=>90, :horsepower=>70, :weight=>1937, :acceleration=>14.2, :year=>76, :origin=>2},
{:name=>"honda civic", :mpg=>33, :cylinders=>4, :displacement=>91, :horsepower=>53, :weight=>1795, :acceleration=>17.4, :year=>76, :origin=>3},
{:name=>"dodge aspen se", :mpg=>20, :cylinders=>6, :displacement=>225, :horsepower=>100, :weight=>3651, :acceleration=>17.7, :year=>76, :origin=>1},
{:name=>"ford granada ghia", :mpg=>18, :cylinders=>6, :displacement=>250, :horsepower=>78, :weight=>3574, :acceleration=>21, :year=>76, :origin=>1},
{:name=>"pontiac ventura sj", :mpg=>18.5, :cylinders=>6, :displacement=>250, :horsepower=>110, :weight=>3645, :acceleration=>16.2, :year=>76, :origin=>1},
{:name=>"amc pacer d/l", :mpg=>17.5, :cylinders=>6, :displacement=>258, :horsepower=>95, :weight=>3193, :acceleration=>17.8, :year=>76, :origin=>1},
{:name=>"volkswagen rabbit", :mpg=>29.5, :cylinders=>4, :displacement=>97, :horsepower=>71, :weight=>1825, :acceleration=>12.2, :year=>76, :origin=>2},
{:name=>"datsun b-210", :mpg=>32, :cylinders=>4, :displacement=>85, :horsepower=>70, :weight=>1990, :acceleration=>17, :year=>76, :origin=>3},
{:name=>"toyota corolla", :mpg=>28, :cylinders=>4, :displacement=>97, :horsepower=>75, :weight=>2155, :acceleration=>16.4, :year=>76, :origin=>3},
{:name=>"ford pinto", :mpg=>26.5, :cylinders=>4, :displacement=>140, :horsepower=>72, :weight=>2565, :acceleration=>13.6, :year=>76, :origin=>1},
{:name=>"volvo 245", :mpg=>20, :cylinders=>4, :displacement=>130, :horsepower=>102, :weight=>3150, :acceleration=>15.7, :year=>76, :origin=>2},
{:name=>"plymouth volare premier v8", :mpg=>13, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>3940, :acceleration=>13.2, :year=>76, :origin=>1},
{:name=>"peugeot 504", :mpg=>19, :cylinders=>4, :displacement=>120, :horsepower=>88, :weight=>3270, :acceleration=>21.9, :year=>76, :origin=>2},
{:name=>"toyota mark ii", :mpg=>19, :cylinders=>6, :displacement=>156, :horsepower=>108, :weight=>2930, :acceleration=>15.5, :year=>76, :origin=>3},
{:name=>"mercedes-benz 280s", :mpg=>16.5, :cylinders=>6, :displacement=>168, :horsepower=>120, :weight=>3820, :acceleration=>16.7, :year=>76, :origin=>2},
{:name=>"cadillac seville", :mpg=>16.5, :cylinders=>8, :displacement=>350, :horsepower=>180, :weight=>4380, :acceleration=>12.1, :year=>76, :origin=>1},
{:name=>"chevy c10", :mpg=>13, :cylinders=>8, :displacement=>350, :horsepower=>145, :weight=>4055, :acceleration=>12, :year=>76, :origin=>1},
{:name=>"ford f108", :mpg=>13, :cylinders=>8, :displacement=>302, :horsepower=>130, :weight=>3870, :acceleration=>15, :year=>76, :origin=>1},
{:name=>"dodge d100", :mpg=>13, :cylinders=>8, :displacement=>318, :horsepower=>150, :weight=>3755, :acceleration=>14, :year=>76, :origin=>1},
{:name=>"honda accord cvcc", :mpg=>31.5, :cylinders=>4, :displacement=>98, :horsepower=>68, :weight=>2045, :acceleration=>18.5, :year=>77, :origin=>3},
{:name=>"buick opel isuzu deluxe", :mpg=>30, :cylinders=>4, :displacement=>111, :horsepower=>80, :weight=>2155, :acceleration=>14.8, :year=>77, :origin=>1},
{:name=>"renault 5 gtl", :mpg=>36, :cylinders=>4, :displacement=>79, :horsepower=>58, :weight=>1825, :acceleration=>18.6, :year=>77, :origin=>2},
{:name=>"plymouth arrow gs", :mpg=>25.5, :cylinders=>4, :displacement=>122, :horsepower=>96, :weight=>2300, :acceleration=>15.5, :year=>77, :origin=>1},
{:name=>"datsun f-10 hatchback", :mpg=>33.5, :cylinders=>4, :displacement=>85, :horsepower=>70, :weight=>1945, :acceleration=>16.8, :year=>77, :origin=>3},
{:name=>"chevrolet caprice classic", :mpg=>17.5, :cylinders=>8, :displacement=>305, :horsepower=>145, :weight=>3880, :acceleration=>12.5, :year=>77, :origin=>1},
{:name=>"oldsmobile cutlass supreme", :mpg=>17, :cylinders=>8, :displacement=>260, :horsepower=>110, :weight=>4060, :acceleration=>19, :year=>77, :origin=>1},
{:name=>"dodge monaco brougham", :mpg=>15.5, :cylinders=>8, :displacement=>318, :horsepower=>145, :weight=>4140, :acceleration=>13.7, :year=>77, :origin=>1},
{:name=>"mercury cougar brougham", :mpg=>15, :cylinders=>8, :displacement=>302, :horsepower=>130, :weight=>4295, :acceleration=>14.9, :year=>77, :origin=>1},
{:name=>"chevrolet concours", :mpg=>17.5, :cylinders=>6, :displacement=>250, :horsepower=>110, :weight=>3520, :acceleration=>16.4, :year=>77, :origin=>1},
{:name=>"buick skylark", :mpg=>20.5, :cylinders=>6, :displacement=>231, :horsepower=>105, :weight=>3425, :acceleration=>16.9, :year=>77, :origin=>1},
{:name=>"plymouth volare custom", :mpg=>19, :cylinders=>6, :displacement=>225, :horsepower=>100, :weight=>3630, :acceleration=>17.7, :year=>77, :origin=>1},
{:name=>"ford granada", :mpg=>18.5, :cylinders=>6, :displacement=>250, :horsepower=>98, :weight=>3525, :acceleration=>19, :year=>77, :origin=>1},
{:name=>"pontiac grand prix lj", :mpg=>16, :cylinders=>8, :displacement=>400, :horsepower=>180, :weight=>4220, :acceleration=>11.1, :year=>77, :origin=>1},
{:name=>"chevrolet monte carlo landau", :mpg=>15.5, :cylinders=>8, :displacement=>350, :horsepower=>170, :weight=>4165, :acceleration=>11.4, :year=>77, :origin=>1},
{:name=>"chrysler cordoba", :mpg=>15.5, :cylinders=>8, :displacement=>400, :horsepower=>190, :weight=>4325, :acceleration=>12.2, :year=>77, :origin=>1},
{:name=>"ford thunderbird", :mpg=>16, :cylinders=>8, :displacement=>351, :horsepower=>149, :weight=>4335, :acceleration=>14.5, :year=>77, :origin=>1},
{:name=>"volkswagen rabbit custom", :mpg=>29, :cylinders=>4, :displacement=>97, :horsepower=>78, :weight=>1940, :acceleration=>14.5, :year=>77, :origin=>2},
{:name=>"pontiac sunbird coupe", :mpg=>24.5, :cylinders=>4, :displacement=>151, :horsepower=>88, :weight=>2740, :acceleration=>16, :year=>77, :origin=>1},
{:name=>"toyota corolla liftback", :mpg=>26, :cylinders=>4, :displacement=>97, :horsepower=>75, :weight=>2265, :acceleration=>18.2, :year=>77, :origin=>3},
{:name=>"ford mustang ii 2+2", :mpg=>25.5, :cylinders=>4, :displacement=>140, :horsepower=>89, :weight=>2755, :acceleration=>15.8, :year=>77, :origin=>1},
{:name=>"chevrolet chevette", :mpg=>30.5, :cylinders=>4, :displacement=>98, :horsepower=>63, :weight=>2051, :acceleration=>17, :year=>77, :origin=>1},
{:name=>"dodge colt m/m", :mpg=>33.5, :cylinders=>4, :displacement=>98, :horsepower=>83, :weight=>2075, :acceleration=>15.9, :year=>77, :origin=>1},
{:name=>"subaru dl", :mpg=>30, :cylinders=>4, :displacement=>97, :horsepower=>67, :weight=>1985, :acceleration=>16.4, :year=>77, :origin=>3},
{:name=>"volkswagen dasher", :mpg=>30.5, :cylinders=>4, :displacement=>97, :horsepower=>78, :weight=>2190, :acceleration=>14.1, :year=>77, :origin=>2},
{:name=>"datsun 810", :mpg=>22, :cylinders=>6, :displacement=>146, :horsepower=>97, :weight=>2815, :acceleration=>14.5, :year=>77, :origin=>3},
{:name=>"bmw 320i", :mpg=>21.5, :cylinders=>4, :displacement=>121, :horsepower=>110, :weight=>2600, :acceleration=>12.8, :year=>77, :origin=>2},
{:name=>"mazda rx-4", :mpg=>21.5, :cylinders=>3, :displacement=>80, :horsepower=>110, :weight=>2720, :acceleration=>13.5, :year=>77, :origin=>3},
{:name=>"volkswagen rabbit custom diesel", :mpg=>43.1, :cylinders=>4, :displacement=>90, :horsepower=>48, :weight=>1985, :acceleration=>21.5, :year=>78, :origin=>2},
{:name=>"ford fiesta", :mpg=>36.1, :cylinders=>4, :displacement=>98, :horsepower=>66, :weight=>1800, :acceleration=>14.4, :year=>78, :origin=>1},
{:name=>"mazda glc deluxe", :mpg=>32.8, :cylinders=>4, :displacement=>78, :horsepower=>52, :weight=>1985, :acceleration=>19.4, :year=>78, :origin=>3},
{:name=>"datsun b210 gx", :mpg=>39.4, :cylinders=>4, :displacement=>85, :horsepower=>70, :weight=>2070, :acceleration=>18.6, :year=>78, :origin=>3},
{:name=>"honda civic cvcc", :mpg=>36.1, :cylinders=>4, :displacement=>91, :horsepower=>60, :weight=>1800, :acceleration=>16.4, :year=>78, :origin=>3},
{:name=>"oldsmobile cutlass salon brougham", :mpg=>19.9, :cylinders=>8, :displacement=>260, :horsepower=>110, :weight=>3365, :acceleration=>15.5, :year=>78, :origin=>1},
{:name=>"dodge diplomat", :mpg=>19.4, :cylinders=>8, :displacement=>318, :horsepower=>140, :weight=>3735, :acceleration=>13.2, :year=>78, :origin=>1},
{:name=>"mercury monarch ghia", :mpg=>20.2, :cylinders=>8, :displacement=>302, :horsepower=>139, :weight=>3570, :acceleration=>12.8, :year=>78, :origin=>1},
{:name=>"pontiac phoenix lj", :mpg=>19.2, :cylinders=>6, :displacement=>231, :horsepower=>105, :weight=>3535, :acceleration=>19.2, :year=>78, :origin=>1},
{:name=>"chevrolet malibu", :mpg=>20.5, :cylinders=>6, :displacement=>200, :horsepower=>95, :weight=>3155, :acceleration=>18.2, :year=>78, :origin=>1},
{:name=>"ford fairmont (auto)", :mpg=>20.2, :cylinders=>6, :displacement=>200, :horsepower=>85, :weight=>2965, :acceleration=>15.8, :year=>78, :origin=>1},
{:name=>"ford fairmont (man)", :mpg=>25.1, :cylinders=>4, :displacement=>140, :horsepower=>88, :weight=>2720, :acceleration=>15.4, :year=>78, :origin=>1},
{:name=>"plymouth volare", :mpg=>20.5, :cylinders=>6, :displacement=>225, :horsepower=>100, :weight=>3430, :acceleration=>17.2, :year=>78, :origin=>1},
{:name=>"amc concord", :mpg=>19.4, :cylinders=>6, :displacement=>232, :horsepower=>90, :weight=>3210, :acceleration=>17.2, :year=>78, :origin=>1},
{:name=>"buick century special", :mpg=>20.6, :cylinders=>6, :displacement=>231, :horsepower=>105, :weight=>3380, :acceleration=>15.8, :year=>78, :origin=>1},
{:name=>"mercury zephyr", :mpg=>20.8, :cylinders=>6, :displacement=>200, :horsepower=>85, :weight=>3070, :acceleration=>16.7, :year=>78, :origin=>1},
{:name=>"dodge aspen", :mpg=>18.6, :cylinders=>6, :displacement=>225, :horsepower=>110, :weight=>3620, :acceleration=>18.7, :year=>78, :origin=>1},
{:name=>"amc concord d/l", :mpg=>18.1, :cylinders=>6, :displacement=>258, :horsepower=>120, :weight=>3410, :acceleration=>15.1, :year=>78, :origin=>1},
{:name=>"chevrolet monte carlo landau", :mpg=>19.2, :cylinders=>8, :displacement=>305, :horsepower=>145, :weight=>3425, :acceleration=>13.2, :year=>78, :origin=>1},
{:name=>"buick regal sport coupe (turbo)", :mpg=>17.7, :cylinders=>6, :displacement=>231, :horsepower=>165, :weight=>3445, :acceleration=>13.4, :year=>78, :origin=>1},
{:name=>"ford futura", :mpg=>18.1, :cylinders=>8, :displacement=>302, :horsepower=>139, :weight=>3205, :acceleration=>11.2, :year=>78, :origin=>1},
{:name=>"dodge magnum xe", :mpg=>17.5, :cylinders=>8, :displacement=>318, :horsepower=>140, :weight=>4080, :acceleration=>13.7, :year=>78, :origin=>1},
{:name=>"chevrolet chevette", :mpg=>30, :cylinders=>4, :displacement=>98, :horsepower=>68, :weight=>2155, :acceleration=>16.5, :year=>78, :origin=>1},
{:name=>"toyota corona", :mpg=>27.5, :cylinders=>4, :displacement=>134, :horsepower=>95, :weight=>2560, :acceleration=>14.2, :year=>78, :origin=>3},
{:name=>"datsun 510", :mpg=>27.2, :cylinders=>4, :displacement=>119, :horsepower=>97, :weight=>2300, :acceleration=>14.7, :year=>78, :origin=>3},
{:name=>"dodge omni", :mpg=>30.9, :cylinders=>4, :displacement=>105, :horsepower=>75, :weight=>2230, :acceleration=>14.5, :year=>78, :origin=>1},
{:name=>"toyota celica gt liftback", :mpg=>21.1, :cylinders=>4, :displacement=>134, :horsepower=>95, :weight=>2515, :acceleration=>14.8, :year=>78, :origin=>3},
{:name=>"plymouth sapporo", :mpg=>23.2, :cylinders=>4, :displacement=>156, :horsepower=>105, :weight=>2745, :acceleration=>16.7, :year=>78, :origin=>1},
{:name=>"oldsmobile starfire sx", :mpg=>23.8, :cylinders=>4, :displacement=>151, :horsepower=>85, :weight=>2855, :acceleration=>17.6, :year=>78, :origin=>1},
{:name=>"datsun 200-sx", :mpg=>23.9, :cylinders=>4, :displacement=>119, :horsepower=>97, :weight=>2405, :acceleration=>14.9, :year=>78, :origin=>3},
{:name=>"audi 5000", :mpg=>20.3, :cylinders=>5, :displacement=>131, :horsepower=>103, :weight=>2830, :acceleration=>15.9, :year=>78, :origin=>2},
{:name=>"volvo 264gl", :mpg=>17, :cylinders=>6, :displacement=>163, :horsepower=>125, :weight=>3140, :acceleration=>13.6, :year=>78, :origin=>2},
{:name=>"saab 99gle", :mpg=>21.6, :cylinders=>4, :displacement=>121, :horsepower=>115, :weight=>2795, :acceleration=>15.7, :year=>78, :origin=>2},
{:name=>"peugeot 604sl", :mpg=>16.2, :cylinders=>6, :displacement=>163, :horsepower=>133, :weight=>3410, :acceleration=>15.8, :year=>78, :origin=>2},
{:name=>"volkswagen scirocco", :mpg=>31.5, :cylinders=>4, :displacement=>89, :horsepower=>71, :weight=>1990, :acceleration=>14.9, :year=>78, :origin=>2},
{:name=>"honda accord lx", :mpg=>29.5, :cylinders=>4, :displacement=>98, :horsepower=>68, :weight=>2135, :acceleration=>16.6, :year=>78, :origin=>3},
{:name=>"pontiac lemans v6", :mpg=>21.5, :cylinders=>6, :displacement=>231, :horsepower=>115, :weight=>3245, :acceleration=>15.4, :year=>79, :origin=>1},
{:name=>"mercury zephyr 6", :mpg=>19.8, :cylinders=>6, :displacement=>200, :horsepower=>85, :weight=>2990, :acceleration=>18.2, :year=>79, :origin=>1},
{:name=>"ford fairmont 4", :mpg=>22.3, :cylinders=>4, :displacement=>140, :horsepower=>88, :weight=>2890, :acceleration=>17.3, :year=>79, :origin=>1},
{:name=>"amc concord dl 6", :mpg=>20.2, :cylinders=>6, :displacement=>232, :horsepower=>90, :weight=>3265, :acceleration=>18.2, :year=>79, :origin=>1},
{:name=>"dodge aspen 6", :mpg=>20.6, :cylinders=>6, :displacement=>225, :horsepower=>110, :weight=>3360, :acceleration=>16.6, :year=>79, :origin=>1},
{:name=>"chevrolet caprice classic", :mpg=>17, :cylinders=>8, :displacement=>305, :horsepower=>130, :weight=>3840, :acceleration=>15.4, :year=>79, :origin=>1},
{:name=>"ford ltd landau", :mpg=>17.6, :cylinders=>8, :displacement=>302, :horsepower=>129, :weight=>3725, :acceleration=>13.4, :year=>79, :origin=>1},
{:name=>"mercury grand marquis", :mpg=>16.5, :cylinders=>8, :displacement=>351, :horsepower=>138, :weight=>3955, :acceleration=>13.2, :year=>79, :origin=>1},
{:name=>"dodge st. regis", :mpg=>18.2, :cylinders=>8, :displacement=>318, :horsepower=>135, :weight=>3830, :acceleration=>15.2, :year=>79, :origin=>1},
{:name=>"buick estate wagon (sw)", :mpg=>16.9, :cylinders=>8, :displacement=>350, :horsepower=>155, :weight=>4360, :acceleration=>14.9, :year=>79, :origin=>1},
{:name=>"ford country squire (sw)", :mpg=>15.5, :cylinders=>8, :displacement=>351, :horsepower=>142, :weight=>4054, :acceleration=>14.3, :year=>79, :origin=>1},
{:name=>"chevrolet malibu classic (sw)", :mpg=>19.2, :cylinders=>8, :displacement=>267, :horsepower=>125, :weight=>3605, :acceleration=>15, :year=>79, :origin=>1},
{:name=>"chrysler lebaron town @ country (sw)", :mpg=>18.5, :cylinders=>8, :displacement=>360, :horsepower=>150, :weight=>3940, :acceleration=>13, :year=>79, :origin=>1},
{:name=>"vw rabbit custom", :mpg=>31.9, :cylinders=>4, :displacement=>89, :horsepower=>71, :weight=>1925, :acceleration=>14, :year=>79, :origin=>2},
{:name=>"maxda glc deluxe", :mpg=>34.1, :cylinders=>4, :displacement=>86, :horsepower=>65, :weight=>1975, :acceleration=>15.2, :year=>79, :origin=>3},
{:name=>"dodge colt hatchback custom", :mpg=>35.7, :cylinders=>4, :displacement=>98, :horsepower=>80, :weight=>1915, :acceleration=>14.4, :year=>79, :origin=>1},
{:name=>"amc spirit dl", :mpg=>27.4, :cylinders=>4, :displacement=>121, :horsepower=>80, :weight=>2670, :acceleration=>15, :year=>79, :origin=>1},
{:name=>"mercedes benz 300d", :mpg=>25.4, :cylinders=>5, :displacement=>183, :horsepower=>77, :weight=>3530, :acceleration=>20.1, :year=>79, :origin=>2},
{:name=>"cadillac eldorado", :mpg=>23, :cylinders=>8, :displacement=>350, :horsepower=>125, :weight=>3900, :acceleration=>17.4, :year=>79, :origin=>1},
{:name=>"peugeot 504", :mpg=>27.2, :cylinders=>4, :displacement=>141, :horsepower=>71, :weight=>3190, :acceleration=>24.8, :year=>79, :origin=>2},
{:name=>"oldsmobile cutlass salon brougham", :mpg=>23.9, :cylinders=>8, :displacement=>260, :horsepower=>90, :weight=>3420, :acceleration=>22.2, :year=>79, :origin=>1},
{:name=>"plymouth horizon", :mpg=>34.2, :cylinders=>4, :displacement=>105, :horsepower=>70, :weight=>2200, :acceleration=>13.2, :year=>79, :origin=>1},
{:name=>"plymouth horizon tc3", :mpg=>34.5, :cylinders=>4, :displacement=>105, :horsepower=>70, :weight=>2150, :acceleration=>14.9, :year=>79, :origin=>1},
{:name=>"datsun 210", :mpg=>31.8, :cylinders=>4, :displacement=>85, :horsepower=>65, :weight=>2020, :acceleration=>19.2, :year=>79, :origin=>3},
{:name=>"fiat strada custom", :mpg=>37.3, :cylinders=>4, :displacement=>91, :horsepower=>69, :weight=>2130, :acceleration=>14.7, :year=>79, :origin=>2},
{:name=>"buick skylark limited", :mpg=>28.4, :cylinders=>4, :displacement=>151, :horsepower=>90, :weight=>2670, :acceleration=>16, :year=>79, :origin=>1},
{:name=>"chevrolet citation", :mpg=>28.8, :cylinders=>6, :displacement=>173, :horsepower=>115, :weight=>2595, :acceleration=>11.3, :year=>79, :origin=>1},
{:name=>"oldsmobile omega brougham", :mpg=>26.8, :cylinders=>6, :displacement=>173, :horsepower=>115, :weight=>2700, :acceleration=>12.9, :year=>79, :origin=>1},
{:name=>"pontiac phoenix", :mpg=>33.5, :cylinders=>4, :displacement=>151, :horsepower=>90, :weight=>2556, :acceleration=>13.2, :year=>79, :origin=>1},
{:name=>"vw rabbit", :mpg=>41.5, :cylinders=>4, :displacement=>98, :horsepower=>76, :weight=>2144, :acceleration=>14.7, :year=>80, :origin=>2},
{:name=>"toyota corolla tercel", :mpg=>38.1, :cylinders=>4, :displacement=>89, :horsepower=>60, :weight=>1968, :acceleration=>18.8, :year=>80, :origin=>3},
{:name=>"chevrolet chevette", :mpg=>32.1, :cylinders=>4, :displacement=>98, :horsepower=>70, :weight=>2120, :acceleration=>15.5, :year=>80, :origin=>1},
{:name=>"datsun 310", :mpg=>37.2, :cylinders=>4, :displacement=>86, :horsepower=>65, :weight=>2019, :acceleration=>16.4, :year=>80, :origin=>3},
{:name=>"chevrolet citation", :mpg=>28, :cylinders=>4, :displacement=>151, :horsepower=>90, :weight=>2678, :acceleration=>16.5, :year=>80, :origin=>1},
{:name=>"ford fairmont", :mpg=>26.4, :cylinders=>4, :displacement=>140, :horsepower=>88, :weight=>2870, :acceleration=>18.1, :year=>80, :origin=>1},
{:name=>"amc concord", :mpg=>24.3, :cylinders=>4, :displacement=>151, :horsepower=>90, :weight=>3003, :acceleration=>20.1, :year=>80, :origin=>1},
{:name=>"dodge aspen", :mpg=>19.1, :cylinders=>6, :displacement=>225, :horsepower=>90, :weight=>3381, :acceleration=>18.7, :year=>80, :origin=>1},
{:name=>"audi 4000", :mpg=>34.3, :cylinders=>4, :displacement=>97, :horsepower=>78, :weight=>2188, :acceleration=>15.8, :year=>80, :origin=>2},
{:name=>"toyota corona liftback", :mpg=>29.8, :cylinders=>4, :displacement=>134, :horsepower=>90, :weight=>2711, :acceleration=>15.5, :year=>80, :origin=>3},
{:name=>"mazda 626", :mpg=>31.3, :cylinders=>4, :displacement=>120, :horsepower=>75, :weight=>2542, :acceleration=>17.5, :year=>80, :origin=>3},
{:name=>"datsun 510 hatchback", :mpg=>37, :cylinders=>4, :displacement=>119, :horsepower=>92, :weight=>2434, :acceleration=>15, :year=>80, :origin=>3},
{:name=>"toyota corolla", :mpg=>32.2, :cylinders=>4, :displacement=>108, :horsepower=>75, :weight=>2265, :acceleration=>15.2, :year=>80, :origin=>3},
{:name=>"mazda glc", :mpg=>46.6, :cylinders=>4, :displacement=>86, :horsepower=>65, :weight=>2110, :acceleration=>17.9, :year=>80, :origin=>3},
{:name=>"dodge colt", :mpg=>27.9, :cylinders=>4, :displacement=>156, :horsepower=>105, :weight=>2800, :acceleration=>14.4, :year=>80, :origin=>1},
{:name=>"datsun 210", :mpg=>40.8, :cylinders=>4, :displacement=>85, :horsepower=>65, :weight=>2110, :acceleration=>19.2, :year=>80, :origin=>3},
{:name=>"vw rabbit c (diesel)", :mpg=>44.3, :cylinders=>4, :displacement=>90, :horsepower=>48, :weight=>2085, :acceleration=>21.7, :year=>80, :origin=>2},
{:name=>"vw dasher (diesel)", :mpg=>43.4, :cylinders=>4, :displacement=>90, :horsepower=>48, :weight=>2335, :acceleration=>23.7, :year=>80, :origin=>2},
{:name=>"audi 5000s (diesel)", :mpg=>36.4, :cylinders=>5, :displacement=>121, :horsepower=>67, :weight=>2950, :acceleration=>19.9, :year=>80, :origin=>2},
{:name=>"mercedes-benz 240d", :mpg=>30, :cylinders=>4, :displacement=>146, :horsepower=>67, :weight=>3250, :acceleration=>21.8, :year=>80, :origin=>2},
{:name=>"honda civic 1500 gl", :mpg=>44.6, :cylinders=>4, :displacement=>91, :horsepower=>67, :weight=>1850, :acceleration=>13.8, :year=>80, :origin=>3},
{:name=>"renault lecar deluxe", :mpg=>40.9, :cylinders=>4, :displacement=>85, :horsepower=>nil, :weight=>1835, :acceleration=>17.3, :year=>80, :origin=>2},
{:name=>"subaru dl", :mpg=>33.8, :cylinders=>4, :displacement=>97, :horsepower=>67, :weight=>2145, :acceleration=>18, :year=>80, :origin=>3},
{:name=>"vokswagen rabbit", :mpg=>29.8, :cylinders=>4, :displacement=>89, :horsepower=>62, :weight=>1845, :acceleration=>15.3, :year=>80, :origin=>2},
{:name=>"datsun 280-zx", :mpg=>32.7, :cylinders=>6, :displacement=>168, :horsepower=>132, :weight=>2910, :acceleration=>11.4, :year=>80, :origin=>3},
{:name=>"mazda rx-7 gs", :mpg=>23.7, :cylinders=>3, :displacement=>70, :horsepower=>100, :weight=>2420, :acceleration=>12.5, :year=>80, :origin=>3},
{:name=>"triumph tr7 coupe", :mpg=>35, :cylinders=>4, :displacement=>122, :horsepower=>88, :weight=>2500, :acceleration=>15.1, :year=>80, :origin=>2},
{:name=>"ford mustang cobra", :mpg=>23.6, :cylinders=>4, :displacement=>140, :horsepower=>nil, :weight=>2905, :acceleration=>14.3, :year=>80, :origin=>1},
{:name=>"honda accord", :mpg=>32.4, :cylinders=>4, :displacement=>107, :horsepower=>72, :weight=>2290, :acceleration=>17, :year=>80, :origin=>3},
{:name=>"plymouth reliant", :mpg=>27.2, :cylinders=>4, :displacement=>135, :horsepower=>84, :weight=>2490, :acceleration=>15.7, :year=>81, :origin=>1},
{:name=>"buick skylark", :mpg=>26.6, :cylinders=>4, :displacement=>151, :horsepower=>84, :weight=>2635, :acceleration=>16.4, :year=>81, :origin=>1},
{:name=>"dodge aries wagon (sw)", :mpg=>25.8, :cylinders=>4, :displacement=>156, :horsepower=>92, :weight=>2620, :acceleration=>14.4, :year=>81, :origin=>1},
{:name=>"chevrolet citation", :mpg=>23.5, :cylinders=>6, :displacement=>173, :horsepower=>110, :weight=>2725, :acceleration=>12.6, :year=>81, :origin=>1},
{:name=>"plymouth reliant", :mpg=>30, :cylinders=>4, :displacement=>135, :horsepower=>84, :weight=>2385, :acceleration=>12.9, :year=>81, :origin=>1},
{:name=>"toyota starlet", :mpg=>39.1, :cylinders=>4, :displacement=>79, :horsepower=>58, :weight=>1755, :acceleration=>16.9, :year=>81, :origin=>3},
{:name=>"plymouth champ", :mpg=>39, :cylinders=>4, :displacement=>86, :horsepower=>64, :weight=>1875, :acceleration=>16.4, :year=>81, :origin=>1},
{:name=>"honda civic 1300", :mpg=>35.1, :cylinders=>4, :displacement=>81, :horsepower=>60, :weight=>1760, :acceleration=>16.1, :year=>81, :origin=>3},
{:name=>"subaru", :mpg=>32.3, :cylinders=>4, :displacement=>97, :horsepower=>67, :weight=>2065, :acceleration=>17.8, :year=>81, :origin=>3},
{:name=>"datsun 210 mpg", :mpg=>37, :cylinders=>4, :displacement=>85, :horsepower=>65, :weight=>1975, :acceleration=>19.4, :year=>81, :origin=>3},
{:name=>"toyota tercel", :mpg=>37.7, :cylinders=>4, :displacement=>89, :horsepower=>62, :weight=>2050, :acceleration=>17.3, :year=>81, :origin=>3},
{:name=>"mazda glc 4", :mpg=>34.1, :cylinders=>4, :displacement=>91, :horsepower=>68, :weight=>1985, :acceleration=>16, :year=>81, :origin=>3},
{:name=>"plymouth horizon 4", :mpg=>34.7, :cylinders=>4, :displacement=>105, :horsepower=>63, :weight=>2215, :acceleration=>14.9, :year=>81, :origin=>1},
{:name=>"ford escort 4w", :mpg=>34.4, :cylinders=>4, :displacement=>98, :horsepower=>65, :weight=>2045, :acceleration=>16.2, :year=>81, :origin=>1},
{:name=>"ford escort 2h", :mpg=>29.9, :cylinders=>4, :displacement=>98, :horsepower=>65, :weight=>2380, :acceleration=>20.7, :year=>81, :origin=>1},
{:name=>"volkswagen jetta", :mpg=>33, :cylinders=>4, :displacement=>105, :horsepower=>74, :weight=>2190, :acceleration=>14.2, :year=>81, :origin=>2},
{:name=>"renault 18i", :mpg=>34.5, :cylinders=>4, :displacement=>100, :horsepower=>nil, :weight=>2320, :acceleration=>15.8, :year=>81, :origin=>2},
{:name=>"honda prelude", :mpg=>33.7, :cylinders=>4, :displacement=>107, :horsepower=>75, :weight=>2210, :acceleration=>14.4, :year=>81, :origin=>3},
{:name=>"toyota corolla", :mpg=>32.4, :cylinders=>4, :displacement=>108, :horsepower=>75, :weight=>2350, :acceleration=>16.8, :year=>81, :origin=>3},
{:name=>"datsun 200sx", :mpg=>32.9, :cylinders=>4, :displacement=>119, :horsepower=>100, :weight=>2615, :acceleration=>14.8, :year=>81, :origin=>3},
{:name=>"mazda 626", :mpg=>31.6, :cylinders=>4, :displacement=>120, :horsepower=>74, :weight=>2635, :acceleration=>18.3, :year=>81, :origin=>3},
{:name=>"peugeot 505s turbo diesel", :mpg=>28.1, :cylinders=>4, :displacement=>141, :horsepower=>80, :weight=>3230, :acceleration=>20.4, :year=>81, :origin=>2},
{:name=>"saab 900s", :mpg=>nil, :cylinders=>4, :displacement=>121, :horsepower=>110, :weight=>2800, :acceleration=>15.4, :year=>81, :origin=>2},
{:name=>"volvo diesel", :mpg=>30.7, :cylinders=>6, :displacement=>145, :horsepower=>76, :weight=>3160, :acceleration=>19.6, :year=>81, :origin=>2},
{:name=>"toyota cressida", :mpg=>25.4, :cylinders=>6, :displacement=>168, :horsepower=>116, :weight=>2900, :acceleration=>12.6, :year=>81, :origin=>3},
{:name=>"datsun 810 maxima", :mpg=>24.2, :cylinders=>6, :displacement=>146, :horsepower=>120, :weight=>2930, :acceleration=>13.8, :year=>81, :origin=>3},
{:name=>"buick century", :mpg=>22.4, :cylinders=>6, :displacement=>231, :horsepower=>110, :weight=>3415, :acceleration=>15.8, :year=>81, :origin=>1},
{:name=>"oldsmobile cutlass ls", :mpg=>26.6, :cylinders=>8, :displacement=>350, :horsepower=>105, :weight=>3725, :acceleration=>19, :year=>81, :origin=>1},
{:name=>"ford granada gl", :mpg=>20.2, :cylinders=>6, :displacement=>200, :horsepower=>88, :weight=>3060, :acceleration=>17.1, :year=>81, :origin=>1},
{:name=>"chrysler lebaron salon", :mpg=>17.6, :cylinders=>6, :displacement=>225, :horsepower=>85, :weight=>3465, :acceleration=>16.6, :year=>81, :origin=>1},
{:name=>"chevrolet cavalier", :mpg=>28, :cylinders=>4, :displacement=>112, :horsepower=>88, :weight=>2605, :acceleration=>19.6, :year=>82, :origin=>1},
{:name=>"chevrolet cavalier wagon", :mpg=>27, :cylinders=>4, :displacement=>112, :horsepower=>88, :weight=>2640, :acceleration=>18.6, :year=>82, :origin=>1},
{:name=>"chevrolet cavalier 2-door", :mpg=>34, :cylinders=>4, :displacement=>112, :horsepower=>88, :weight=>2395, :acceleration=>18, :year=>82, :origin=>1},
{:name=>"pontiac j2000 se hatchback", :mpg=>31, :cylinders=>4, :displacement=>112, :horsepower=>85, :weight=>2575, :acceleration=>16.2, :year=>82, :origin=>1},
{:name=>"dodge aries se", :mpg=>29, :cylinders=>4, :displacement=>135, :horsepower=>84, :weight=>2525, :acceleration=>16, :year=>82, :origin=>1},
{:name=>"pontiac phoenix", :mpg=>27, :cylinders=>4, :displacement=>151, :horsepower=>90, :weight=>2735, :acceleration=>18, :year=>82, :origin=>1},
{:name=>"ford fairmont futura", :mpg=>24, :cylinders=>4, :displacement=>140, :horsepower=>92, :weight=>2865, :acceleration=>16.4, :year=>82, :origin=>1},
{:name=>"amc concord dl", :mpg=>23, :cylinders=>4, :displacement=>151, :horsepower=>nil, :weight=>3035, :acceleration=>20.5, :year=>82, :origin=>1},
{:name=>"volkswagen rabbit l", :mpg=>36, :cylinders=>4, :displacement=>105, :horsepower=>74, :weight=>1980, :acceleration=>15.3, :year=>82, :origin=>2},
{:name=>"mazda glc custom l", :mpg=>37, :cylinders=>4, :displacement=>91, :horsepower=>68, :weight=>2025, :acceleration=>18.2, :year=>82, :origin=>3},
{:name=>"mazda glc custom", :mpg=>31, :cylinders=>4, :displacement=>91, :horsepower=>68, :weight=>1970, :acceleration=>17.6, :year=>82, :origin=>3},
{:name=>"plymouth horizon miser", :mpg=>38, :cylinders=>4, :displacement=>105, :horsepower=>63, :weight=>2125, :acceleration=>14.7, :year=>82, :origin=>1},
{:name=>"mercury lynx l", :mpg=>36, :cylinders=>4, :displacement=>98, :horsepower=>70, :weight=>2125, :acceleration=>17.3, :year=>82, :origin=>1},
{:name=>"nissan stanza xe", :mpg=>36, :cylinders=>4, :displacement=>120, :horsepower=>88, :weight=>2160, :acceleration=>14.5, :year=>82, :origin=>3},
{:name=>"honda accord", :mpg=>36, :cylinders=>4, :displacement=>107, :horsepower=>75, :weight=>2205, :acceleration=>14.5, :year=>82, :origin=>3},
{:name=>"toyota corolla", :mpg=>34, :cylinders=>4, :displacement=>108, :horsepower=>70, :weight=>2245, :acceleration=>16.9, :year=>82, :origin=>3},
{:name=>"honda civic", :mpg=>38, :cylinders=>4, :displacement=>91, :horsepower=>67, :weight=>1965, :acceleration=>15, :year=>82, :origin=>3},
{:name=>"honda civic (auto)", :mpg=>32, :cylinders=>4, :displacement=>91, :horsepower=>67, :weight=>1965, :acceleration=>15.7, :year=>82, :origin=>3},
{:name=>"datsun 310 gx", :mpg=>38, :cylinders=>4, :displacement=>91, :horsepower=>67, :weight=>1995, :acceleration=>16.2, :year=>82, :origin=>3},
{:name=>"buick century limited", :mpg=>25, :cylinders=>6, :displacement=>181, :horsepower=>110, :weight=>2945, :acceleration=>16.4, :year=>82, :origin=>1},
{:name=>"oldsmobile cutlass ciera (diesel)", :mpg=>38, :cylinders=>6, :displacement=>262, :horsepower=>85, :weight=>3015, :acceleration=>17, :year=>82, :origin=>1},
{:name=>"chrysler lebaron medallion", :mpg=>26, :cylinders=>4, :displacement=>156, :horsepower=>92, :weight=>2585, :acceleration=>14.5, :year=>82, :origin=>1},
{:name=>"ford granada l", :mpg=>22, :cylinders=>6, :displacement=>232, :horsepower=>112, :weight=>2835, :acceleration=>14.7, :year=>82, :origin=>1},
{:name=>"toyota celica gt", :mpg=>32, :cylinders=>4, :displacement=>144, :horsepower=>96, :weight=>2665, :acceleration=>13.9, :year=>82, :origin=>3},
{:name=>"dodge charger 2.2", :mpg=>36, :cylinders=>4, :displacement=>135, :horsepower=>84, :weight=>2370, :acceleration=>13, :year=>82, :origin=>1},
{:name=>"chevrolet camaro", :mpg=>27, :cylinders=>4, :displacement=>151, :horsepower=>90, :weight=>2950, :acceleration=>17.3, :year=>82, :origin=>1},
{:name=>"ford mustang gl", :mpg=>27, :cylinders=>4, :displacement=>140, :horsepower=>86, :weight=>2790, :acceleration=>15.6, :year=>82, :origin=>1},
{:name=>"vw pickup", :mpg=>44, :cylinders=>4, :displacement=>97, :horsepower=>52, :weight=>2130, :acceleration=>24.6, :year=>82, :origin=>2},
{:name=>"dodge rampage", :mpg=>32, :cylinders=>4, :displacement=>135, :horsepower=>84, :weight=>2295, :acceleration=>11.6, :year=>82, :origin=>1},
{:name=>"ford ranger", :mpg=>28, :cylinders=>4, :displacement=>120, :horsepower=>79, :weight=>2625, :acceleration=>18.6, :year=>82, :origin=>1},
{:name=>"chevy s-10", :mpg=>31, :cylinders=>4, :displacement=>119, :horsepower=>82, :weight=>2720, :acceleration=>19.4, :year=>82, :origin=>1}
]

